﻿using System;
using System.Windows;
using System.Windows.Input;
using System.Windows.Interactivity;

namespace ReflectionIT.Phone.Behaviors {

    /// <summary>
    /// Double Tap gesture trigger used to invoke an action in Blend
    /// </summary>
    /// <remarks>
    /// (C)2010 Reflection IT BV - Fons Sonnemans
    /// </remarks>
    public class DoubleTapGestureTrigger : TriggerBase<UIElement> {

        private long _start;
        private bool _prevTap;
        private const double TapSpeed = 500;

        /// <summary>
        /// Attach from the appropriate events.
        /// </summary>
        protected override void OnAttached() {
            base.OnAttached();
            this.AssociatedObject.ManipulationCompleted += AssociatedUIElement_ManipulationCompleted;
        }

        /// <summary>
        /// Detach from the appropriate events.
        /// </summary>
        protected override void OnDetaching() {
            base.OnDetaching();

            this.AssociatedObject.ManipulationCompleted -= AssociatedUIElement_ManipulationCompleted;
        }

        void AssociatedUIElement_ManipulationCompleted(object sender, ManipulationCompletedEventArgs e) {
            if (!e.IsTapEvent && _prevTap && TimeSpan.FromTicks(DateTime.Now.Ticks - this._start).TotalMilliseconds < TapSpeed) {
                this.InvokeActions(e);
            } else {
                _start = DateTime.Now.Ticks;
                _prevTap = e.IsTapEvent;
            }
        }

    }


}