﻿using System;
using System.Windows;
using System.Windows.Input;
using System.Windows.Interactivity;
using System.Windows.Threading;

namespace ReflectionIT.Phone.Behaviors {

    /// <summary>
    /// Touch and Hold gesture trigger used to invoke an action in Blend
    /// </summary>
    /// <remarks>
    /// (C)2010 Reflection IT BV - Fons Sonnemans
    /// </remarks>
    public class TouchAndHoldGestureTrigger : TriggerBase<UIElement> {

        private DispatcherTimer _timer = new DispatcherTimer();

        public TouchAndHoldGestureTrigger() {
            _timer.Interval = new TimeSpan(0, 0, 1);
            _timer.Tick += new EventHandler(_timer_Tick);
        }

        void _timer_Tick(object sender, EventArgs e) {
            _timer.Stop();
            this.InvokeActions(null);
        }

        /// <summary>
        /// Attach from the appropriate events.
        /// </summary>
        protected override void OnAttached() {
            base.OnAttached();

            // Insert code that you want to run when the Trigger is attached to an object.
            this.AssociatedObject.ManipulationStarted += AssociatedObject_ManipulationStarted;
            this.AssociatedObject.ManipulationDelta += AssociatedObject_ManipulationDelta;
            this.AssociatedObject.ManipulationCompleted += AssociatedUIElement_ManipulationCompleted;
        }

        /// <summary>
        /// Detach from the appropriate events.
        /// </summary>
        protected override void OnDetaching() {
            base.OnDetaching();

            this.AssociatedObject.ManipulationStarted -= AssociatedObject_ManipulationStarted;
            this.AssociatedObject.ManipulationDelta -= AssociatedObject_ManipulationDelta;
            this.AssociatedObject.ManipulationCompleted -= AssociatedUIElement_ManipulationCompleted;

        }

        void AssociatedObject_ManipulationDelta(object sender, ManipulationDeltaEventArgs e) {
            _timer.Stop();
        }

        void AssociatedObject_ManipulationStarted(object sender, ManipulationStartedEventArgs e) {
            _timer.Start();
        }


        private void AssociatedUIElement_ManipulationCompleted(object sender, ManipulationCompletedEventArgs e) {
            _timer.Stop();
        }


    }

 
}